package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````8!T```````!``````````&B3````
M````!0```$``.``'`$``$P`2``8````$````0`````````!``````````$``
M````````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!````````R`$````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````#R#````````/(,`````````
M$`````````$````&````$(X````````0G@```````!">````````D`0`````
M``#H%``````````0`````````@````8````@C@```````"">````````()X`
M``````#@`0```````.`!````````"`````````!1Y71D!@``````````````
M```````````````````````````````````````````0`````````%+E=&0$
M````$(X````````0G@```````!">````````\`$```````#P`0````````$`
M````````+VQI8B]L9"UM=7-L+7)I<V-V-C0N<V\N,0`````````1````3```
M``0````(````()`0``5`!(`H`!$$@(8$A((!```)``0(B(`00;H``H@`````
M3````$\```!2````4P```%D```!:````6P```%T```!>````7P```&$```!B
M````8P```&4``````````````&I_FGS.WD<M;\7?'R[%F[;49-1\(?_D#MEQ
M6!SZH6Q@PN4_++(!BV]"^M>'XD?&`;OCDGQ5PSS29Z_,9H@'<--#1=7L<U"?
MV#-BV^T4C"7,/\_2;/]A\F%_J9R;X*<""FL:GE"CX/M)````````````````
M```````````````````````````#``@`$!P```````````````````$````2
M``````````````````````````D````1`````````````````````````,\!
M```1`````````````````````````'$!```2````````````````````````
M`!`````2`````````````````````````*X!```2````````````````````
M`````!@````2`````````````````````````!\````2````````````````
M`````````-<"```B`````````````````````````-P!```2````````````
M`````````````+H!```2`````````````````````````"@````@````````
M`````````````````/$"```A`````````````````````````$`````2````
M`````````````````````$8````2`````````````````````````$T````2
M`````````````````````````)H"```2`````````````````````````,`"
M```2`````````````````````````%0````2````````````````````````
M``("```2`````````````````````````%L````2````````````````````
M`````(@"```2`````````````````````````&(````2````````````````
M`````````&H````2`````````````````````````'$"```2````````````
M`````````````'(````2`````````````````````````'@````2````````
M`````````````````($````@`````````````````````````/\#```B````
M`````````````````````+("```2`````````````````````````)T````2
M`````````````````````````*(````2`````````````````````````.T!
M```1`````````````````````````(\"```2````````````````````````
M`"\"```2`````````````````````````*D````2````````````````````
M`````"$"```2`````````````````````````#<#```2````````````````
M`````````/`"```1`````````````````````````%,"```2````````````
M`````````````-T"```2`````````````````````````/("```1````````
M`````````````````+`````2`````````````````````````*H"```2````
M`````````````````````+D````1`````````````````````````'\!```2
M`````````````````````````,L````B`````````````````````````-H`
M```@`````````````````````````/`````2````````````````````````
M`,\"```2`````````````````````````#\"```2````````````````````
M`````/4````2`````````````````````````/L````@````````````````
M`````````'P"```2`````````````````````````!4!```2````````````
M`````````````)\!```2`````````````````````````!H!```2````````
M`````````````````&$"```2`````````````````````````(X!```2````
M`````````````````````"`!```2`````````````````````````#$!```2
M`````````````````````````/T!```2`````````````````````````',`
M```2``````````````````````````X"```2````````````````````````
M`$@"```2`````````````````````````+D"```2````````````````````
M`````#<!```2`````````````````````````*("```2````````````````
M`````````$L!```2`````````````````````````/@!```2````````````
M`````````````%(!```2`````````````````````````%D!```2````````
M`````````````````.\"```A`````````````````````````&H!```2````
M`````````````````````.H"```2``@`$!P```````!0`0```````)4#```2
M``@`8B@```````""!0```````%`$```2``@`C"\```````!,`````````%8#
M```2``@`P",````````"`````````+@#```2``@`Y"T```````"H`0``````
M`"4$```2``@`PB,```````"@`0```````/`#```0`!``H*(`````````````
M`````(,#```2``@`Y"<```````!^`````````*(#```2``@`/"(````````P
M`````````*H#```2``@`C"<```````!``````````,X#```2``@`,D$`````
M``#\`````````.,#```2``@`8B4````````8`````````$L$```0`!``^+(`
M`````````````````!P#```2``@`>!T````````B``````````4$```2``@`
M>B4```````"\`````````-D#```1``X`0*`````````(`````````!X$```0
M``\`H*(``````````````````',#```0``\`H*(``````````````````/4#
M```2``@`8!T``````````````````/P#```2``@`WD````````!4````````
M`#P$```0``X``*```````````````````&<#```0`!``^+(`````````````
M`````"4#```2``@`S"<````````8`````````$`#```2``@`L"(````````0
M`0```````#($```2``@`+D(```````",`0```````!$$```2``@`-B8`````
M``!6`0````````!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R
M:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R
M8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&QS=&%T`&-L;W-E
M9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S
M=')C:'(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI
M>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I
M<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?97)R;F]?;&]C871I;VX`
M;6MD:7(`<'1H<F5A9%]G971S<&5C:69I8P!M96UC<'D`<W1R;&5N`%]?<W1A
M8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!03%]D;U]U;F1U;7``4&5R;%]N97=8
M4U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L
M7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`
M<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO
M861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C
M`')E861D:7(`<W!R:6YT9@!S=')N8W!Y`'-T<F1U<`!S=')T;VL`<'1H<F5A
M9%]A=&9O<FL`9G!R:6YT9@!?9FEN:0!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E
M;G9I<F]N`&QI8G!E<FPN<V\`;&EB8RYM=7-L+7)I<V-V-C0N<V\N,0!?<W1A
M<G1?8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE8P!?7T)34U]%3D1?7P!?7U-$051!
M7T)%1TE.7U\`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN
M:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`<VAA7W5P
M9&%T90!M>5]P87)?<&P`<&%R7V)A<V5N86UE`%]?8G-S7W-T87)T`'-H85]I
M;FET`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?961A=&$`<&%R7V9I;F1P
M<F]G`'-H85]F:6YA;`!?7T1!5$%?0D5'24Y?7P!?96YD`'!A<E]C;&5A;G5P
M`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%`````````!">````````
M`P`````````V'@```````!B>`````````P````````#H'0````````"@````
M`````P``````````H````````!"@`````````P````````#00P```````!B@
M`````````P````````#@0P```````""@`````````P````````#H0P``````
M`"B@`````````P````````#P0P```````#"@`````````P````````#X0P``
M`````$"@`````````P````````!X1P```````""B`````````P`````````0
M'````````"BB`````````@````,``````````````#"B`````````@````0`
M`````````````#BB`````````@````H``````````````$"B`````````@``
M``T``````````````$BB`````````@```!T``````````````%"B````````
M`@```!X``````````````%BB`````````@```"(``````````````&"B````
M`````@```"L``````````````&BB`````````@```"X``````````````'"B
M`````````@```#```````````````'BB`````````@```#$`````````````
M`("B`````````@```#8``````````````(BB`````````@```#L`````````
M`````)"B`````````@```#P``````````````)BB`````````@```$$`````
M`````````%B@````````!0````(``````````````&"@````````!0````4`
M`````````````&B@````````!0````8``````````````'"@````````!0``
M``<``````````````'B@````````!0````@``````````````("@````````
M!0````D``````````````(B@````````!0````L``````````````)"@````
M````!0````P``````````````)B@````````!0````\``````````````*"@
M````````!0```!```````````````*B@````````!0```!$`````````````
M`+"@````````!0```!(``````````````+B@````````!0```!,`````````
M`````,"@````````!0```!0``````````````,B@````````!0```!4`````
M`````````-"@````````!0```!8``````````````-B@````````!0```!<`
M`````````````."@````````!0```!@``````````````.B@````````!0``
M`!D``````````````/"@````````!0```!H``````````````/B@````````
M!0```!L```````````````"A````````!0```!P```````````````BA````
M````!0```!\``````````````!"A````````!0```"```````````````!BA
M````````!0```"$``````````````""A````````!0```",`````````````
M`"BA````````!0```"0``````````````#"A````````!0```"4`````````
M`````#BA````````!0```"8``````````````$"A````````!0```"<`````
M`````````$BA````````!0```"D``````````````%"A````````!0```"H`
M`````````````%BA````````!0```"P``````````````&"A````````!0``
M`"T``````````````&BA````````!0```"\``````````````'"A````````
M!0```#(``````````````'BA````````!0```#,``````````````("A````
M````!0```#0``````````````(BA````````!0```#4``````````````)"A
M````````!0```#<``````````````)BA````````!0```#@`````````````
M`*"A````````!0```#D``````````````*BA````````!0```#H`````````
M`````+"A````````!0```#T``````````````+BA````````!0```#X`````
M`````````,"A````````!0```#\``````````````,BA````````!0```$``
M`````````````-"A````````!0```$(``````````````-BA````````!0``
M`$,``````````````."A````````!0```$0``````````````.BA````````
M!0```$4``````````````/"A````````!0```$8``````````````/BA````
M````!0```$<```````````````"B````````!0```$@```````````````BB
M````````!0```$D``````````````!"B````````!0```$L`````````````
M`)>#```S`\-!`[Z#?1,#0_V3@H-]$U,3`(.R@@!G``X`%XX```,^CGQG`PX`
M$P```!>.```#/@Y\9P,.`!,````7C@```SZ.>V<##@`3````%XX```,^#GMG
M`PX`$P```!>.```#/HYZ9P,.`!,````7C@```SX.>F<##@`3````%XX```,^
MCGEG`PX`$P```!>.```#/@YY9P,.`!,````7C@```SZ.>&<##@`3````%XX`
M``,^#GAG`PX`$P```!>.```#/HYW9P,.`!,````7C@```SX.=V<##@`3````
M%XX```,^CG9G`PX`$P```!>.```#/@YV9P,.`!,````7C@```SZ.=6<##@`3
M````%XX```,^#G5G`PX`$P```!>.```#/HYT9P,.`!,````7C@```SX.=&<#
M#@`3````%XX```,^CG-G`PX`$P```!>.```#/@YS9P,.`!,````7C@```SZ.
M<F<##@`3````%XX```,^#G)G`PX`$P```!>.```#/HYQ9P,.`!,````7C@``
M`SX.<6<##@`3````%XX```,^CG!G`PX`$P```!>.```#/@YP9P,.`!,````7
MC@```SZ.;V<##@`3````%XX```,^#F]G`PX`$P```!>.```#/HYN9P,.`!,`
M```7C@```SX.;F<##@`3````%XX```,^CFUG`PX`$P```!>.```#/@YM9P,.
M`!,````7C@```SZ.;&<##@`3````%XX```,^#FQG`PX`$P```!>.```#/HYK
M9P,.`!,````7C@```SX.:V<##@`3````%XX```,^CFIG`PX`$P```!>.```#
M/@YJ9P,.`!,````7C@```SZ.:6<##@`3````%XX```,^#FEG`PX`$P```!>.
M```#/HYH9P,.`!,````7C@```SX.:&<##@`3````%XX```,^CF=G`PX`$P``
M`!>.```#/@YG9P,.`!,````7C@```SZ.9F<##@`3````%XX```,^#F9G`PX`
M$P```!>.```#/HYE9P,.`!,````7C@```SX.96<##@`3````%XX```,^CF1G
M`PX`$P```!>.```#/@YD9P,.`!,````7C@```SZ.8V<##@`3````%XX```,^
M#F-G`PX`$P```!>.```#/HYB9P,.`!,````7C@```SX.8F<##@`3````%XX`
M``,^CF%G`PX`$P```!>.```#/@YA9P,.`!,````Y<2[H,N0JSC``#`AH"`;\
M(O@F]._PW^@7A@```S8&9[*%%X4```,UY67O\'_1EX<``(.W)U^#QP<`%X0`
M`!,$Y&B7A```@[1D8(WC[_!?W`CL`>4%1>_PO^7O\'_KB$#O\!_SA6<^E:,+
M!:2(0._P/_*#1Z5*D^<G`",%]4J(0._P'_&#1Z5*D^<7`",%]4IR11L&-0`1
M)0X%,N#O\%_EJH8(Y$)E<D@"9AQA`4><XI<W``"3AX>JG.:7AP``@[=G-YSJ
MES<``).'QZF<[IL'1P`%!XX'FP4'`+:78\0%!PAL([`'``%'EP4``).%15?O
M\!_,JH0)Y0AL[_!_W:J$"&SO\/_5%R4``!,%I7WO`$`=$>T<:('K%R4``!,%
M!77O`"`<".@(:!G![Q`@)0AL[_`?Z>_PW[7B<$)T)H6B="%A@H"3%3<`JI6,
M88SC0;>7D0``DX$!U`J%EX4``).%90L3<0'_":`,01,&A0"!1Q>'```#-X=+
MEX8``(.VADP7A0```S4%2>6Q%X4``!,%Y2J7AP``DX=G*F.(IP"7AP``@[>G
M29'#@H>"@!>%```3!<4HEX4``).%12B)C9/7-4#]D;Z5A869Q9>'``"#MV=*
MD<."AX*`01$BX!>$```3!$1+@T<$``;DE>N7AP``@[='1Y''%X4```,UI1^"
ME^_PO_B7AP``@[?'0I''%V4``!,%I5&"EX5'(P#T`*)@`F1!`8*`EX<``(.W
M)T29ST$1!N27A0``DX5%1A=E```3!<5.@I>B8$$!C;>%MSEQ)O0&_"+X2O!.
M[%+H5N1:X(%$.<V7AP``@[?'/@.Z!P"!1&,'"@2JB:Z**H83!]`#@T<&`*GK
M.P0V05*)$PO0`X,T"0"5Q"*&SH4FA>_P7[`=[;.'A`"#QP<`8YIG`S,)24$3
M63E`$P84`".@*@&RE.)P0G0">>)I0FJB:@)K)H6B="%A@H#CB.?Z!095MR$)
M1;\!$2+H%X0```,T)#<<8$P`!NP^Y._PG_4B9QQ@8P3W`._P_\WB8$)D!6&"
M@#EQ)O27A```@[1D-)Q@(OA*\$[L!OPJA#[D$PE!`)>)``"#N4DRRH4BA>_P
M?_$9Y2)GG&!C#_<`[_"_R9)'$Y<W`(.W"0"ZEYAGF.-IWZ$'Y;_B<$)THG0"
M>>)I(6&"@!%QSNV7B0``@[EI+H.W"0"&_:+YIO7*\=+IUN7:X5[]8OEF]6KQ
M;NT^Y2G%@T<%`*J$J</O\/^-*HD-S1<J```3"NI`ERH``).*:D47*P``$PMK
M19,+@0!]7+UL$6U*A>_P/Y8JA!'M2H7O\)^?)H7O\#^T*F>#MPD`8PCW!N_P
M7[]-!-*%(H7O\+^2:=G6A2*%[_`?DF'5)H7O\)^\JHTBA>_P'[P[A:T`"27O
M\'^6VH6BAB:&JHWO\+^WWH5NA>_P/[-C#X4!XD>S]Y<!@2=CF:<!;H7O\+_R
M;H7O\'^PO;]NA>_P_Y'-O^YP3G2N=`YY[FE.:JYJ#FOJ>TI\JGP*?>IM$6&"
M@'%Q)NV7A```@[3D'9Q@+``B\0;U*H0^Y>_P/Y,5Y>)'/6?YCQ%G8X7G`"EG
M8YCG`(E%(H7O\'^!$S45`"IGG&!C!O<`[_!_L@%%S;^J<`ITZF1-88*`'7%2
M^!>*```#.HH8@S<*`*+HIN2&[,K@3OQ6]%KP7NP#QP4`/N23!]`#JH0NA&,4
M]P`3A!4`(H7O\-^L*HE,`":%[_`?U*J)'<'O\+^K8V(E!X-'!``%!(4)HX_Y
M_O7[(F>#-PH`8P+W#N_POZJ7B@``@[IJ$8.["@"!2=Z'F&--XY>'``"3AZ<7
MF$.;A2D`C@59RUZ%[_#O\R.PJ@!IT8.W"@`;AQD`#@>ZER.P!P!.PB:%$P?0
M`X-'!0"9PV.4YPB229>*``"#N@H,!9V3ESD`@[D*``D)2I6^F>_PC_TCL*D`
M-=T21X.W"@`3!M`##@>ZEYQC`\<$`(4$OH8C@.<`A0<9P^,8Q_X3!]`#(X#F
M``-'!``%!(4'HX_G_G7[@;>A!X4IH;\%1RZ%F,/O\&_X*HL5U1.6.0#>A>_P
MC_@CL&H!L;\%!86_YF!&9*9D!FGB>4)ZHGH">^)K)6&"@$$1!N27AP``@[>'
M`8A#[_!_E:)@EV8``).&A@H7A@```S8&`Y<E``"3A84<00$9ND$1(N`7A```
M`S2$_@A`!N3O\%^2[_#?^PA`[_"_D0)DHF`7)P``$P<G38%'NH87%@``$P:F
MM)<E``"3A64:00%O\$_D77$F_/EREX0``(.T)/N&Y*+@2OB<8!:1"604"!,'
MA`$VEQSC>7GO\*_D(1F3!P0"RI<8"#.)YP`%9*J&%R<``!,'1Q<7)@``$P9&
M%Y,%%`!*A>_P[]W]5V,=]0"!1PEG%`AA!S:7%&.88&.*Y@CO\#^-8W.D``*0
MXT(%_GUTB6=!%).'!P*BEQ@(,X3G``5FHH5*A>_PS_0;!@4`XT`&_!L%%@`R
MY._PK^.JAT79(F8S"<4`8W2%`.-O)/M]=XEF01>3A@8"NI88"#:78W7W`#*7
MX^+G^@5G!0?C3L?X_74)9\$5$P<'`BZ7%`@^A;,%UP#O\/^!JH<C``D`C;>)
M8A:1IF`&9.)T0GD^A6%A@H#%O5%Q7O67BP``@[LKZH.W"P#]<@5GHO&F[=+A
MAO7*Z<[E5OU:^6+Q9NT3!X<(%I&JA`J7%R4``!,%10@NA!SC[_`_KRJ*DP7P
M`B:%[_!/XQW!IH47)0``$P5%!^_P'\R%9Y.'APB*EYAC@[<+`&,*]Q#O\._[
M)H7O\(_ZFPH%`)<E``"3A84%(H7O\&_TA6?]>1.)B?\3AP<)2I>3B8GW,PDG
M`!.'!PF3AP<)!6M.EXJ7*H07+```$PQ,];,))P"SC&=!6=2#1P0`D>-BA&,+
M"@"BA5*%[_"OR9<E``"3A>7_0<TBA>_PK_,!)9,&\`(;!_7_LP?D``/&!P!C
M"=8"FX<:`#V=XU9E]::'%R<``!,'1_VBAA<F```3!B;]A65*A>_P[[\%)6-W
MJP`"D".`!P`ZA76_SH5*A>_P;^<-Z8.GC/@]9_F/(6=CD^<"A45*A>_P[[L)
M[<J%%R4``!,%Y?;O\+^[2H7O\(_,JH3-O9<E``"3A87V`47O\&_E*H21MX5B
M%I&N<":%#G3N9$YIKFD.:NIZ2GNJ>PI\ZFQM88*`JH>3!O`"`\<'`!'C@H"%
M!^,;U_X^A<6_`<6#1P4`F><7)0``$P5EY&_P;\8!$0;L*N3O\,_DHF43!O7_
MDP?P`BZ68_?%!`-'!@!C#_<"DP?P`F/_Q0(#1P8`DP;V_V,7]P*3!_`"?19C
M]L4``T<&`.,+]_X-CA,')@"%9V/JYP0%!F/ZQP("D'T69;\VAM&WXYG%_`/'
M!0"3!_`"%R4``!,%I=QC!O<`%R4``!,%9>GB8`5AE;\7A0``$P4%SN_P#\@7
MA0``$P5%S>)@!6&"@`%%Y;\Y<2+X%X0```,TY,(<8!,&(`*790``DX4%S`J%
M!OP^]._PK]87)0``$P5EY>_PWXL7)0``$P6EY>_P'XL7)0``$P5EY>_P7XH7
M)0``$P6EY>_PGXD7)0``$P5EY>_PWX@7)0``$P6EY>_P'X@7)0``$P5EW>_P
M7X<7)0``$P4EY>_PGX87)0``$P5EY>_PWX47)0``$P6EY>_P'X47)0``$P5E
MV^_P7X07)0``$P4EY>_PWX`!R:J%%R4``!,%)>+O\'^>%R4``!,%Y>3O\`__
MJH49Q1<E```3!67,[_"_G!<E```3!:7D[_!/_:J%%R4``!,%1=6)[1<E```3
M!27D[_#/^ZJ%'<47)0``$P4EW._P?YF7)0``DX7EY!<E```3!>78[_`_F")W
M'&!C`?<"[_"OR"E&ER4``).%Q>$3!1$![_"/HWGUDP6Q`76_XG!"="%A@H!!
M$2+@%X0``!,$A(<80`;D_5=C$O<"%R4``!,%Y=7O\(_T`4<!R8-'!0")QY.'
M!_TS-_``&,`(0*)@`F1!`8*`01$&Y._P#\,!)>_PKZ@1P0AAHF!!`8*``1$B
MZ"J$%R4``!,%9=L&[";D2N#O\*_OHH4)Q8-'!0"JA)GK0F3B8*)D`FD7)0``
M$P4%V05AR;#O\$^?'>DBA>_PS[LJB2:%[_!/NTJ5"07O\,^5ER4``).%!<<F
MAY<F``"3AF;%(H8JB>_P+[;*A56_XF!"9*)D`FD%88*`"7'2ZA>*```#.BJ@
M@S<*`*%FX7*B^L[NAOZF]LKRUN;:XE[^8OH3AX82%I$*EQSC8723AP83HI<S
MA"<`ER<``).')[(C./3LER<``).'Y[$C//3LJHDC,`3N$P8``Y=U``"3A05U
M$P4$\._P3Z^7)P``DX<'LR,T].Z7)P``DX?'LB,X].XC/`3N%R4``!,%Q;CO
M\._?,<&#1P4`*H25S^_P/^ZA9Y.'AQ**EYAC@S<*`&,$]P#O\(^MH6(6D?9P
MMG06>?9I5FJV:A9K\GM2?"*%5G0986_PCXOO\!_I*H0-[>%TH6>3A(3NDX<'
M$Z:7LX0G`(A@$>47)```$P1DQ2FH[_#OV!GAH03MMX-'!0#EW^_PSX<JA&79
M(H7O\"^F!@4%!>_PKX"JBJJ$%RD``!,)J<(#1@0`8Q0&$.%TH6>3A`3PDX<'
M$Z:7LX0G`(!@'<`BA>_PS],JA&,*!0Z#1P4`8X8'#N_P[^MC`@4.(H7O\.^!
M*H3A=*%GDX0$[9.'!Q.FE[.$)P`!Z`.Y!`!C!0D`@T<)`-7O(H7O\$^>*HE6
MA>_PSYT[":D`&PE)0$J%[^#_]]:'%R<``!,'A[J7)@``DX8&J"*&ER4``).%
MY;FJA._PSY>3!0`<)H7O\"^1_5=C$O4([_"/CQA!Q4=C#/<&EW<``(.W1WT#
MM@D`B&.FAI<E``"3A46W[_!/A@%$H6>3AX<2BI>88X,W"@#C'/?HH6(6D?9P
M(H6V=%9T%GGV:59JMFH6:_)[4GP988*`)H7*A>_PKY`%!(D$Y;6A!/V]2H7O
M\`_="<5*A>_@/_,JA*$$%;=A=*%GDP4$\Y.'!Q.NE[.%)P`FA>_@7^\JBP7!
MEW<``(.W1W0#M@D`B&.FAI<E``"3A46R[^!?_86_H6>3AP<3HI<SA"<`@R<$
M]#UG^8\19^.6Y_R#*H3T[_`/C@$EXY^J^H,G!/03!P`<D_?W'^.7Y_I*A>_@
M7^4JA!<E```3!>6R[_"/NF,0!12#N@D`5H7O\(^(&PD%`(U'8]LG!1,%R?^7
M)0``DX7EL%:5[^#?VR'AD4=C"OD`;3E6F0-'"0"3!_`"8Q;W`@.YB0!C`@D"
M2H7O\&^$C4=C_*<`<167)0``DX6EK4J5[^`?V!'ARHKO\%^]8Q`%&H%%5H7O
MX-_CJHEC"048"4:Y5>_@_]-A>2%KDPJ)_Y,'"Q/6E[.*)P`91M:%3H7OX#_R
MDP<+$\J7BI<#QX?_1><#QY?_DP8P!&,?UP@#QJ?_DP80!&,9U@B#QK?_8Y7F
M"(/&Q_\3!X`$8Y_F!@/'U_^3!U`$8QGW!@E&DP5@_$Z%[^`?S1,&D`+6A4Z%
M[^!?[)<G``"3AP>Q5H>7)@``DX9FA":&ER4``).%1:(BA>_@/_0FA>_@W^ZB
MA1<5```3!>5_[_"OQ2*%[_#?M=VS`[D)`._@_]6JA4J%[_"/\JJ*XQL%ZGVU
M`4:!14Z%[^!?QN\0X$)A>:%G$PN)_Y.'!Q/:EZJ*,XLG`"%FVH5.A>_@/^0;
M!@4`8T[`!DZ%[^!?X:%I$PL)^Y.'"1/:ES.+)P#6A5J%[Q"@4Q,)B?R3APD3
MRI<SB2<`@4KA>1<L```3#.R*T4NS!UL!`\8'`$J%XH6%"N_@_^@)">.6>O^A
M9I.'!A,3AXG\SI>3A@83BI>ZEB.(!_XSAR8`ER<``).'AZ$IM]J%5H7O$,`]
MO;>7)0``DX7%@Q<5```3!<5Y[_`/M^_@'[LJAY<G``"3AZ>>EQ8``).&)G(F
MAI<E``"3A061(H7OX/_A_5E%29<J``"3BFJ<EQL``).+ZV\7+```$PSLCY,%
M`!PBA>_@G]GC&S7K[^`?V!Q!XY8GZ^_@?[4%*RJ'5HC:A]Z&)H;BA2*%[^`_
MW<&_.7$B^!=T```#-`1'"$`&_";T2O!.[._@?]JJA`A`[^#_V8/'!`NC"/4*
M%Q4``!,%)6WO\,^-$<D#1P4`DP<0`V,5]P"#1Q4`F</O\)^`"$#OX-_6C48%
M1I<E``"3A46([^#?OJJ$%<D(0._@/]6<:!<F```3!D:'C&/OX#^_G&B<8]Q'
MF]=G`86+@<L(0._@_]*<:(QC[^!_KPA`EW0``).$A$7OX)_1C48%1I<E``"3
MA06$[^"?N2J)(<47%0``$P6%7N_PKX0JY!G)"$#OX/_.@S<)`2)FC&/OX#^Y
M%:#O\,^^JHD(0&.+"0;OX!_-@S<)`4Z&C&/OX%^W3H7OX/_'"$#OX)_+*HD(
M0._@'\L%1I<5``"3A25^[^`_G*J%%Q8``!,&QGY*A>_@/[0(0._@W\BC"`4*
M%Q4``!,%Q57OX/_\B.@=X8AD[_!?DXCH$>T7%0``$P4E?._@/YSOX/_%F&2#
M-PD!$&.]MXAHDP4`'._@O[_%1ZJ&8P#U`IL'%0`%1V-[]P"<9)!H%Q4``!,%
M!7N,8^_@?YCB<$)THG0">>)I(6&"@`$1!NPBZ";D*H3O\$_>[_"/W*J$[_#/
M_@W%!<2#1P0`C<.7%0``DX4E82:%[^"?I6.9I``BA4)DXF"B9`5A;^!?^^)@
M0F2B9`5A@H`7?@```SX.*8,W#@`3`0'3.`#]6$%C(S01+",P@2PC/)$J(S@A
M*R,T,2LC,$$K(SQ1*2,X82DC-/$HDP6%`Q,/A0<ZB)/8"`*W#O\`$P,#\)1A
MH05!").7A@$3EH8`,W;6`;/W%P'1CQ/6A@`S=F8`T8\;UH8!T8\C./C^D]>&
M`A/6!@*S]V<`X9+5CY,6A@&S]A8!(@;5CS-VU@'1CR,\^/[C%[_Z_5>3!0<@
M@9,P8S1W(0>QCA!GL8X#-H?_L8X3EA8`_8+1COV.-/_C$;?^`S\%`(,^!0*W
MCX):DU:_`1,77P!5CZ)FDX^?F0,X!0&#.(4!`S.%`/Z6?8_VEC:7LT88`;/V
M9@"SQA8!-I>3%>,!DU8C`-6-0F:S\O4`LT98`+/VY@%^EGV/L\8&`4:6DU.W
M`;*6$Q97`#-F=@"REC/T]@`3%N\!DU8O`%6.XF:QC?F-_I;"EK/%50"35+0!
MMI63%E0`Q8ZVE9,6YP$)@]F.`G>S<_8`-8Y^EV&._8VZDC-&=@`6EA.750"3
MTK4!,V=7`#J6$Q?D`0F`08\B=+/T]@"YCGZ4[8Y]CJ*3I8X35+8!GI:3$U8`
ML^.#`)Z6DY/E`8F!L^6S`,)SLW+W`"V/_I-QC_V.GI0S1U<`)I>3DU8`D]2V
M`;/CDP`>E^)TDQ/F`0F",^;#`#/T]0"QC?Z4]8U]CZ:2H8V35+<!EI63$E<`
ML^*2`):5AF23DN8!B8*SYM(`LW/V`#6._I1YCOV-)I0S1G8`D]2U`2*6$Y15
M`$6,(I:F9!,4YP$)@T&/L_+V`+F._I3MCGV.II.SQE8`DU2V`9Z6DQ-6`+/C
MDP">EL9DDY/E`8F!L^6S`#-T]P`MC_Z4<8_]CJ:2(8^3U+8!%I>3DE8`L^*2
M`!:7YF23$N8!"8(SYL(`L_/U`+&-_I3UC7V/)I2SQ74`DU2W`:*5$Q17`$6,
MHI6&=!.4Y@&)@L&.LW+V`#6._I1YCOV-II,S1E8`D]2U`1Z6DY-5`+/CDP`>
MEJ9TDQ/G`0F#,^?C`#/T]@"YCOZ4[8Y]CJ:2H8Z35+8!EI:3$E8`L^*2`):6
MQG23DN4!B8&SY;(`LW/W`"V/_I1QC_V.)I0S1W<`D]2V`2*7$Y16`$6,(I?F
M=!,4Y@$)@D&.L_+U`+&-_I3UC7V/II.SQ54`DU2W`9Z5DQ-7`+/CDP">E8ID
MDY/F`8F"L^;3`#-T]@`UCOZ4>8[]C::2(8Z3U+4!%I:3DE4`L^*2`!:6JF23
M$N<!"8,SY^(`L_/V`+F._I3MCGV.)I2SQG8`DU2V`:*6$Q16`$6,HI;*9!.4
MY0&)@<&-LW+W`"V/_I1QC_V.II,S1U<`D]2V`1Z7DY-6`+/CDP`>EY,3Y@$)
M@C/FPP#J8S/T]0"QC?Z3]8U]CYZ2H8V34[<!EI63$E<`L^)R`+/R\@"6E9.2
MY@&)@K/BT@"*=K-T]@`S1E8`>8ZVGS/Y]0`ECJ*?$Q3G`0F#68RRGY,660`3
M5KD!*G?1CC/&@@#]CBV.M_79;I.#%;JVGS/Z_P`>E[J4DU:Z`1,76@!]CE6/
M?8\FECJ6RG83%^D!$UDI`#-I)P$S1R0!L_+R`)Z6LT_W`3-[]@"S__\`EI83
M5[L!_I:3'UL`L^_O`),9Z@%J=Q-:*@"SZ4D!LT4Y`;/__P#^EGV,'I<MCK/Z
M]@!]CB*7CF\REY.56@`3UKH!DQ3K`1-;*P"SY&0!T8W]C3/&F0`NES-Y^0">
MG[&.,W3W`/V.RI^N9;:?$Q94`)-6M`&3DNH!D]HJ`+/B4@%5CGV.L\94`+*?
ML_GY`)Z5-8\S^O\`?8_.E;J5DQ9:`!-7N@'9COV.3F83&>0!"8`S:8D`MI6S
M^O4`,\<B`?V,D]:Z`1Z6LT_W`1.76@"S__\`)I95CWV/?I83%.H!$UHJ`#-D
M1`$ZENYFLWGV`#-'B0"YC9.?60`3U[D!L_+R`)Z6L^_O`).4Z@$.=Y/:*@"S
MY%0!_8V6EK/__P"NEK-%E`#^EC-Y^0`>ERV.,_KV`'V.2I>N?S*7DQ5:`!-6
MN@&3DND!D]DI`+/B,@'1C?V-,\94`"Z7?8R>G[&.LWKW`/V.HI_.=;:?$Y9:
M`)/6N@$3&>H!$UHJ`#-I20%5CGV.L\8B`;*?_8R>E36/L_G_`'V/II6ZE9.6
M60`3U[D!V8[]CFYV$Y3J`9/:*@`S9%0!MI4S^O4`,T>)`+/R\@"35KH!'I:S
M3_<!$Q=:`+/__P`6EE6/?8]^EI.4Z0&3V2D`L^0T`3J6DF:S>O8`,T>4`+F-
MDY]:`!/7N@$S>?D`GI:S[^\`DQ+J`3)G$UHJ`+/B0@']C<J6L___`*Z6L\54
M`/Z6?8P>ERV.L_GV`'V.(I?2;S*7DY59`!/6N0$3F>H!D]HJ`#-I60'1C?V-
M,\8B`2Z7_8R>G[&.,WKW`/V.II_R9;:?$Q9:`)-6N@$3E.D!D]DI`#-D-`%5
MCGV.LT:)`+*?L_+R`)Z5-8^S^O\`?8^6E;J5DY9:`!/7N@'9COV.$G:3&>H!
M$UHJ`+/I20&VE;/T]0`S1S0!,WGY`)/6M`$>EK-/]P$3EU0`L___`$J658]]
MCWZ6DY+J`9/:*@"SXE(!.I:R=C-Z]@`SQUD`N8V3'UH`$U>Z`7V,GI:S[^\`
M$YGD`5)WB8`S:9D`_8VBEK/__P"NEK/%(@'^EK/Y^0`>ERV.,_3V`'V.3I?R
M?S*7DQ54`!-6M`&3%.H!$UHJ`+/D1`'1C?V-,T:9`"Z7L_+R`)Z?L8ZS>?<`
M_8Z6GQ/6N0&VGY.660#1CI9E$Q;D`0F`08ZVG[/&Q``S>?D`GI4UC[/__P!]
MC\J5D]:_`;J5$Y=?`%6/DY+I`9/9*0"SXC(!NI7]C3-T]@"S]_(`,V96`#-W
M]`"V8S-V]@&W]L8C68Z*!GU7`9.3AL;-MI/YC)Z4)I:3DU4`D]2U`;/CDP`>
MEI.3[P&3WR\`L^_S`;/S[P"SXO(!L_1W`+/RL@"SXI(`UF1YCK:4)I2BDI-4
MM@$3%%8`18RBDA.4Y0&)@<&-L_3E`+/OOP`S]),`L__/`+/OCP!V9+/RX@`V
ME**7OI\3U+(!DY=2`,&/OI^3%^8!"8)=CC-TY@#1C;/WA`"S]54`W8V6=[/_
M[P"VE[Z3GI63EU\`D]._`;/G=P"^E9.7X@&3TB(`L^=7`+/SYP!=CK-R=``S
M=O8!,V96`+9R^8VVDI:4)I:3DE4`D]2U`;/BD@`6EI.2[P&3WR\`L^_R`;/R
M[P"SY_<!L_13`.V/Q8_6='F.MI0FE**7DU2V`1,45@!%C**7$Y3E`8F!P8TS
M].4`L^^_`+/T@@"S_\\`L^^?`/9T^8^VE*:3GI^3U+<!DY-7`+/CDP">GY,3
MY@$)@C/FPP"S<^8`T8VS='0`_8W%C9IDL__O`+:4II*6E9/4OP&3DE\`L^*2
M`):5DY+G`8F#L^?R`+/RYP!=CK/T4P`S=O8!18ZZ9/F-MI0FE"*6D]2U`1.4
M50!%C"*6$Y3O`9/?+P"S;_0!,_3O`+/G]P&S]((`[8_%C]ID>8ZVE*:3GI>3
M5+8!DQ-6`+/CDP">EY.3Y0&)@;/ELP"S\^4`L^^_`+-T=`"S_\\`L^^?`/ID
M^8^VE*:2EI^3U+<!DY)7`+/BD@"6GY,2Y@$)@C/FP@"S<N8`T8VS]%,`_8W%
MC9ITL__O`+:4)I2BE9/4OP$3E%\`18RBE1.4YP&)@\&/,_3G`%V.L_2"`#-V
M]@%%CKIT^8VVE*:3'I:3U+4!DY-5`+/CDP`>EI.3[P&3WR\`L^_S`;/S[P"S
MY_<!LW1T`.V/Q8_:='F.MI2FDI:7DU2V`9,25@"SXI(`EI>3DN4!B8&SY;(`
ML_+E`+/OOP"S]%,`L__/`+/OGP#Z=/F/MI0FE**?D]2W`1.45P!%C**?$Q3F
M`0F"08XS=.8`T8VS]((`_8W%C9YDL__O`+:4II.>E9/4OP&3DU\`L^.3`)Z5
MDY/G`8F#L^?S`+/SYP!=CK-T=``S=O8!18Z^9/F-MI2FDA:6D]2U`9.250"S
MXI(`%I:S<N8`$Y;O`9/?+P"S;_8!L_3O`+/G]P$S]I,`[8_1CUYF-I8RE**7
M$Y92`!/4L@%!CK*7$Y;E`8F!T8TS].4`L^^_`#/VA`"S_U\`L^_/`'YF^8\V
MEK*3GI\3EE<`D].W`3-F=@!YCK*?$Y;B`9/2(@"S8E8`,_GB`+/E50`S=B0!
M_8W1C1YVL_GO`/YSLI:FEJZ6$Y99`)/5N0&3E.<!B8/=C$V.M[>8,KYU>8Z*
M!Y.'9QVREC/ZY@`SQI(`OI4NE#-&]@&3%5H`DU^Z`7F.L^7U`?F-(I8NEI.5
MZ0&3V2D`L^DU`;//-`&SS]\`WG8S=.8`DU6T`;Z6-IF3%E0`L__O`,V.^8Z3
M$NH!RI\36BH`,^I"`;:?,_OO`+/&20$UCI,26P"35KL!^8R^D[/BT@"3&N0!
M@S8!(`F`L^J*`*:3>8ZS15H!L_+B`!Z6%I:S^>D`OI:SS_4!,WGF`+/_[P#.
MEOZ6DQ59`)-?N0&SY?4!DQ3K`8,R@2`36RL`L^1D`?F-KI:SQ9H`,WKJ`+Z2
M+8ZS\^8`>8[2DK*2DY]3`!/6LP$3%.D!@S4!(1-9*0`S9"0!L^_/`+/_[P`S
MQH0`_I*S^NH`OI6QCC/[X@#YCM:5MI43%EL`DU:[`56.>8X3F>,!@S^!(9/3
M(P`S:7D`LI4S^N4`LT8D`?F,$U:Z`;Z?L\)6`),66@"S\N(`II_1COF.EI^3
M$^L!$ULK`+:?L^-C`0,V`2*S^>\`LT9Y`+6-DY)9`)/6N0%YC#Z6L^+2`),4
MZ@&#-H$B$UHJ`+/D1`'YC2*6L_+B`"Z6L\63`!:6,WGI`+Z6L\_U`;-ZY@"S
M_^\`RI;^EI.56@"3W[H!L^7U`1.4Z0&#,@$CD]DI`#-D-`'YC:Z6L\6$`+/S
MXP"^DBV.,_KF`'F.GI*RDI,?6@`35KH!$YGJ`8,U@2.3VBH`,VE9`;/OSP"S
M_^\`,T8D`?Z2^8R^E;&.L_GB`/F.II6VE1.660"3UKD!58YYCI,3Z@&#/P$D
M$UHJ`+/C0P&RE;/ZY0"S1GD`>8P3UKH!OI^SPE8`DY9:`+/RX@"BG]&.^8Z6
MGY.4Z0&3V2D`L^0T`;:?`S:!)#/Z[P"SQI,`M8V3$EH`DU:Z`3-YZ0`^EK/B
MT@`3E.H!@S8!)9/:*@`S9%0!^8U*EK/RX@`NEK/%A``6EK/SXP"^EK//]0&S
M>>8`L__O`)Z6_I:3E5D`D]^Y`;/E]0$3&>H!@S*!)1-:*@`S:4D!^8VNEK-%
M)`'YC+Z2+8ZS^N8`>8ZFDK*2DY]:`!/6N@&3D^D!@S4!)I/9*0"SXS,!L^_/
M`+/_[P`S1GD`_I)YC+Z5L8XS^N(`^8ZBE;:5$Q9:`)-6N@%5CGF.DY3J`8,_
M@2:3VBH`LI6SY%0!L_GE`+/&DP`S>>D`$]:Y`;Z?L\)6`).660"S\N(`RI_1
MCA,4Z@$#-@$G$UHJ`/F.,V1$`9:?MI^SQH0`,_GO`+/SXP`^EK6-^8V35KD!
M'I:3$UD`+I:SX],`DY7I`8,V@2>3V2D`L^4U`;/SXP"RDS-&M`"^EOF,LT_V
M`;/RXP"S_^\`II;^EA.64@"3W[(!,V;V`;*6`S8!*),?Z0$362D`L^\O`;*7
M,\;U`?J7>8PS1G8`^8YYCJ*7LI<3W[8!$Y96`#-FY@&RE_F/'.&3E^(!D](B
M`+/G5P`^F)J6QI_VE?F.,WCH`+/_[P!MCQCQ`S>!*(,W#@`4Y2,X!0$C//4!
M8P3W`._0W[.#,($L`S0!+(,T@2L#.0$K@SF!*@,Z`2J#.H$I`SL!*1,!`2V"
M@$$1$P4`"`;D[]"_BC<G16<3!Q<P&.$71P```S?'(QCE-W==3`8'$P?GSQCI
M-U<R$!,'9T<8[3=WZ6$&!Q,'!Q\8\2,T!0(C.`4"(RP%!J)@00&"@#EQ(O@F
M]`;\2O!.[%+H5N08=9,7-@`JA+J7@A>!D[*$8_7G`!AY!0<8^1AX'/0H7)/7
MU`&ZEQSX$PF$`S')DP<`!#N'IT";B00`8U27`)L)!P!*E6-WM0"S!S4!8_/U
M``*0,XHU`6/TI0#C:T7_3H;OT/^A/%P[AS<!.-R3!P`$8Q_W`B*%[^`?XKN$
M-$'2A1,*\`.3"H0'8TR:`F-VN0"S!YD`X^[U^F/V)0&SAY4`XVCY^B:&2H7O
MT'^=)-SB<$)THG0">>)I0FJB:B%A@H!C=+D`X^95^9.)!01C]"4!XV`Y^1,&
M``1*A>_07YHBA>_@?]N;A`3\SH5YOSEQ(O@F]$KP4NA:X`;\3NQ6Y(/7A0*#
MN84"$XN%`QN9AP";EP<!F]<'`9O7AP"S9_D`$YD'`X/7!0,3!@#X@[H%`QN:
MAP";EP<!F]<'`9O7AP"S9_H`$YH'`Y/7.0"3]_<#DX87`!N'%P#:ER.`QP"3
M!X`#JH0NA!-9"0,36@H#,P7;`&/?UPX3!@`$&9Z!1>_0+^HBA>_@7]$3!H`#
M@45:A>_0#^F3UXH!(PCT!I/:"@&3UXD!D]D)`:,(5`<C&40'(PKT!J,*-`<C
M&R0'(H7OX+_-'&`BA>&#(X#T`!Q@P8.C@/0`'&"A@R.!]``<8*.!]``<9.&#
M(X+T`!QDP8.C@O0`'&2A@R.#]``<9*.#]``<:.&#(X3T`!QHP8.CA/0`'&BA
M@R.%]``<:*.%]``<;.&#(X;T`!QLP8.CAO0`'&RA@R.']``<;*.']``<<.)P
M`GGA@R.(]``<<.)I0FK!@Z.(]``<<*)J`FNA@R.)]``<<$)THXGT`*)T(6%O
MT$_[$P:``QF>@44AOP```````"]T;7``````+@````````!005)?5$U01$E2
M````````5$U01$E2``!414U01$E2`%1%35``````5$U0``````!54T52````
M`%5315).04U%```````````N+@```````"5S+R5S````1'EN84QO861E<CHZ
M8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E
M>&4``````"]P<F]C+R5I+R5S``````!005)?5$5-4```````````4$%27U!2
M3T=.04U%`````#H`````````+P`````````E<R5S)7,``%!%4DPU3$E"````
M``````!015),3$E"`%!%4DPU3U!4``````````!015),24\``%!!4E])3DE4
M24%,25I%1`!005)?4U!!5TY%1```````4$%27T-,14%.`````````%!!4E]$
M14)51P````````!005)?0T%#2$4`````````4$%27T=,3T)!3%]$14)51P``
M````````4$%27T=,3T)!3%]435!$25(`````````4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X``````````%!!4E]#3$5!3CT````````Q````
M`````$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````<&%R+0`````E
M<R5S)7,E<P``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@
M86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!0051(`````'!A<FP`
M````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S
M)7-T96UP+25U+25U)7,``````````!@`````````<&5R;``````P````````
M`%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4R````56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H``````````"UE````````+2T```````!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!
M1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#
M86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I
M;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R
M7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E
M;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A8
M6"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*
M4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M
M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@
M=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII
M9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@
M,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L
M;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D
M9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U
M=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z
M.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N
M9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG
M(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3
M,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G
M;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T
M85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N
M(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE(&]R(&QA<W0["FUY("1B=68["FUY
M("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@
M,3`R-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE
M*2!["B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E
M("1C:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T[
M"GT@96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]
M"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P
M;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D
M4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!
M1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I
M8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@
M,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@
M)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L
M:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*
M96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D
M("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]
M(#T*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC
M<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L
M("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O
M<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D
M=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I
M;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R
M(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO
M9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@
M,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R
M87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S
M="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE
M="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P
M96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<&%R(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D
M<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=
M('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG
M="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P
M;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.
M5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI
M+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME
M>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B
M72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?
M(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO
M861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X
M("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I
M;G0H)&QO861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I
M.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!
M3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@
M9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@
M(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M
M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*
M96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M
M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N
M*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I
M9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;
M4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]
M('5N9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC
M;&]S92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT
M96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E
M;B!A<R`B)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE
M+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D
M9F@I.PIC;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T
M.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE
M7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C
M86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@
M;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F
M:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N
M;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q
M=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR
M97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE
M"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P
M96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP
M(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.
M5GM005)?5$5-4'TB72D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![
M(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M
M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES
M1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N
M86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE
M*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T
M7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI
M('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A
M;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T
M<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(ETI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]
M?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI
M;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D
M8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU
M."P@,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E
M('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM
M>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\
M.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N
M86UE(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C
M='@M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L
M<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@
M)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@
M)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B
M.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U
M;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O
M<B!D:64@<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@
M)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N
M86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL
M;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M
M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A
M)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF
M:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD
M9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N
M9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B![
M"FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N
M.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H
M<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@``<&5R;'AS:2YC`````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@``````````")J\WO````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````0````````#Z`@````````$`````
M````!0,````````/`````````%P$````````#`````````````````````T`
M```````````````````9`````````!">````````&P`````````(````````
M`!H`````````&)X````````<``````````@`````````]?[_;P````#H`0``
M``````4`````````6`P````````&`````````,@"````````"@````````!Z
M!`````````L`````````&``````````5`````````````````````P``````
M``!(H`````````(`````````0`4````````4``````````<`````````%P``
M```````P$P````````<`````````V!`````````(`````````)@'````````
M"0`````````8`````````!@```````````````````#[__]O``````$```@`
M````^?__;P`````*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_____````````````````````````````````
M````````````````````````````````````````````````__________\`
M`````````'`8````````<!@```````!P&````````'`8````````<!@`````
M``!P&````````'`8````````<!@```````!P&````````'`8````````<!@`
M``````!P&````````'`8````````<!@```````!P&````````'`8````````
M<!@```````!P&````````'`8````````<!@```````!P&````````'`8````
M````<!@```````!P&````````'`8````````<!@```````!P&````````'`8
M````````<!@```````!P&````````'`8````````<!@```````!P&```````
M`'`8````````<!@```````!P&````````'`8````````<!@```````!P&```
M`````'`8````````<!@```````!P&````````'`8````````<!@```````!P
M&````````'`8````````<!@```````!P&````````'`8````````<!@`````
M``!P&````````'`8````````<!@```````!P&````````'`8````````<!@`
M```````@G@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1T-#.B`H06QP:6YE(#$P+C,N,5]G:70R,#(Q,#DR,2D@,3`N,RXQ
M(#(P,C$P.3(Q```N<VAS=')T86(`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YR96QA+F1Y;@`N<F5L82YP;'0`+G1E>'0`+G)O9&%T80`N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F1A
M=&$`+F=O=``N8G-S`"YC;VUM96YT````````````````````````````````
M````````````````````````````````````````````````````````````
M"P````$````"`````````,@!````````R`$````````:````````````````
M`````0```````````````````!,```#V__]O`@````````#H`0```````.@!
M````````W``````````#``````````@````````````````````=````"P``
M``(`````````R`(```````#(`@```````)`)````````!`````(````(````
M`````!@`````````)0````,````"`````````%@,````````6`P```````!Z
M!````````````````````0```````````````````"T````$`````@``````
M``#8$````````-@0````````6`(````````#``````````@`````````&```
M```````W````!````$(`````````,!,````````P$P```````$`%````````
M`P````\````(`````````!@`````````/`````$````&`````````'`8````
M````<!@```````"@`P``````````````````$``````````0`````````$$`
M```!````!@`````````0'````````!`<````````JB<`````````````````
M``(```````````````````!'`````0````(`````````P$,```````#`0P``
M`````'@_```````````````````(````````````````````3P````$````"
M`````````#B#````````.(,````````$````````````````````!```````
M`````````````%D````.`````P`````````0G@```````!".````````"```
M``````````````````@`````````"`````````!E````#P````,`````````
M&)X````````8C@````````@````````````````````(``````````@`````
M````<0````8````#`````````"">````````((X```````#@`0````````0`
M````````"``````````0`````````'H````!`````P``````````H```````
M``"0````````2`````````````````````@```````````````````"`````
M`0````,`````````2*````````!(D````````%@"```````````````````(
M``````````@`````````A0````@````#`````````*"B````````H)(`````
M``!8$```````````````````"````````````````````(H````!````,```
M`````````````````*"2````````,0````````````````````$`````````
M`0`````````!`````P````````````````````````#1D@```````),`````
;```````````````!````````````````````
